<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>CollectionSetupModel</name>
    <message>
        <location filename="../src/collectionsetupmodel.cpp" line="97"/>
        <source>Select folders for music collection</source>
        <translation>Vyberte složky pro hudební sbírku</translation>
    </message>
</context>
<context>
    <name>CollectionTree</name>
    <message>
        <location filename="../src/collectiontree.cpp" line="56"/>
        <location filename="../src/collectiontree.cpp" line="128"/>
        <location filename="../src/collectiontree.cpp" line="358"/>
        <source>Artist</source>
        <translation>Umělec</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="321"/>
        <source>Add to PlayList&amp;1</source>
        <translation>Přidat do seznamu skladeb &amp;1</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="323"/>
        <source>Add to PlayList&amp;2</source>
        <translation>Přidat do seznamu skladeb &amp;2</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="326"/>
        <source>Re-scan collection</source>
        <translation>Obnovit hudební sbírku</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="357"/>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="359"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="106"/>
        <location filename="../src/collectiontree.cpp" line="360"/>
        <source>Genre</source>
        <translation>Žánr</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="117"/>
        <location filename="../src/collectiontree.cpp" line="361"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="362"/>
        <source>Location</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="365"/>
        <source>Meta Information</source>
        <translation>Popisné informace</translation>
    </message>
</context>
<context>
    <name>CollectionTreeItem</name>
    <message>
        <location filename="../src/collectiontreeitem.cpp" line="97"/>
        <source>All</source>
        <translation type="unfinished">celek</translation>
    </message>
</context>
<context>
    <name>CollectionWidget</name>
    <message>
        <source>yy</source>
        <translation type="obsolete">rr</translation>
    </message>
    <message>
        <location filename="../src/collectionwidget.cpp" line="61"/>
        <source>Random Tracks</source>
        <translation>Náhodné skladby</translation>
    </message>
    <message>
        <location filename="../src/collectionwidget.cpp" line="64"/>
        <source>Enter space-separated terms to filter collection</source>
        <translation>Zadejte mezerou oddělená hledaná slova pro filtrování sbírky</translation>
    </message>
</context>
<context>
    <name>Core::Internal::FancyTabWidget</name>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="646"/>
        <source>Large sidebar</source>
        <translation>Velký postranní panel</translation>
    </message>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="647"/>
        <source>Small sidebar</source>
        <translation>Malý postranní panel</translation>
    </message>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="648"/>
        <source>Plain sidebar</source>
        <translation>Prostý postranní panel</translation>
    </message>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="649"/>
        <source>Tabs on top</source>
        <translation>Karty nahoře</translation>
    </message>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="650"/>
        <source>Icons on top</source>
        <translation>Ikony nahoře</translation>
    </message>
</context>
<context>
    <name>DjBrowser</name>
    <message>
        <location filename="../src/djbrowser.cpp" line="69"/>
        <source>Add a new AutoDj</source>
        <translation>Přidat nového automatického diskžokeje</translation>
    </message>
    <message>
        <location filename="../src/djbrowser.cpp" line="80"/>
        <source>Add a new record case for current AutoDj</source>
        <translation>Přidat nový kufr s deskami pro nynějšího automatického diskžokeje</translation>
    </message>
</context>
<context>
    <name>DjFilterWidget</name>
    <message>
        <location filename="../src/djfilterwidget.ui" line="20"/>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="354"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="214"/>
        <source>Record Case</source>
        <translation>Kufr s deskami</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1192"/>
        <source>Remove this record case</source>
        <translation>Odstranit tento kufr s deskami</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1195"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1685"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#e1e1e1;&quot;&gt;Path&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#e1e1e1;&quot;&gt;Adresář&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="331"/>
        <location filename="../src/djfilterwidget.ui" line="388"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1142"/>
        <source>Activate this record case</source>
        <translation>Použít tento kufr s deskami</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1145"/>
        <source>set</source>
        <translation>set</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1148"/>
        <source>Alt+J</source>
        <translation>Alt+J</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1172"/>
        <source>Count</source>
        <translation>Počet</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="2664"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Confirm the remove&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Potvrdit odstranění&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="2676"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="452"/>
        <source>how many records per turn</source>
        <translation>Kolik nahrávak přehrát v jednom kole</translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="obsolete">Adresář</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="2167"/>
        <source>Genre</source>
        <translation>Žánr</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="2617"/>
        <source>Artist</source>
        <translation>Umělec</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="320"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:11pt;&quot;&gt;count of records which fit to this filter(s)&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt; text-decoration: underline;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:11pt;&quot;&gt;Počet záznamů odpovídajících filtru (filtrům)&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt; text-decoration: underline;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>?</source>
        <translation type="obsolete">?</translation>
    </message>
    <message>
        <source>select directory</source>
        <translation type="obsolete">Vybrat adresář</translation>
    </message>
    <message>
        <source>^</source>
        <translation type="obsolete">^</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.cpp" line="157"/>
        <location filename="../src/djfilterwidget.cpp" line="203"/>
        <source>of</source>
        <translation>z</translation>
    </message>
</context>
<context>
    <name>DjSettings</name>
    <message>
        <location filename="../src/djsettings.ui" line="26"/>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <location filename="../src/djsettings.ui" line="47"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
<context>
    <name>DjWidget</name>
    <message>
        <location filename="../src/djwidget.ui" line="20"/>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="100"/>
        <source>AutoDJ</source>
        <translation>Diskžokej</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="137"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;DJ Main&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;DJ Main&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="208"/>
        <source>Start a session of this DJ</source>
        <translation>Zahájení zasedání tohoto diskžokeje</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="222"/>
        <source>Remove this DJ</source>
        <translation>Odstranit tohoto diskžokeje</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="225"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="281"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Confirm the remove&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Potvrdit odstranění&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="290"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;fdadfaf&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;DJ Main&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;fdadfaf&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;DJ Main&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="253"/>
        <source>TextLabel</source>
        <translatorcomment>no need to translate</translatorcomment>
        <translation>Textový štítek</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="139"/>
        <source>tracks</source>
        <translation>skladeb</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="140"/>
        <source>hours</source>
        <translation>hodin</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="136"/>
        <source>cases</source>
        <translation>kufrů</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="135"/>
        <source>This Dj plays: </source>
        <translation>Tento diskžokej hraje:</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="136"/>
        <source>case</source>
        <translation>kufr</translation>
    </message>
</context>
<context>
    <name>Knowthelist</name>
    <message>
        <location filename="../src/knowthelist.ui" line="14"/>
        <source>Knowthelist</source>
        <translation>Knowthelist</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="1141"/>
        <source>Fader</source>
        <translation>Prolínač</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="1836"/>
        <source>AutoD&amp;J</source>
        <translation>Auto&amp;DJ</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="1839"/>
        <location filename="../src/knowthelist.ui" line="5724"/>
        <source>Alt+J</source>
        <translation>Alt+J</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="2499"/>
        <source>Set</source>
        <translation>Nastav</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="4845"/>
        <source>FadeNo&amp;w</source>
        <translation>Prolínat nyní</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="4848"/>
        <source>Alt+W</source>
        <translation>Alt+W</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5096"/>
        <location filename="../src/knowthelist.ui" line="5777"/>
        <source>Gain</source>
        <translation>Zesílení</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5721"/>
        <source>AGC</source>
        <translation>AGC</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5798"/>
        <location filename="../src/knowthelist.ui" line="5822"/>
        <source>Low</source>
        <translation>Basy</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5843"/>
        <location filename="../src/knowthelist.ui" line="5867"/>
        <source>Mid</source>
        <translation>Středy</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5891"/>
        <location filename="../src/knowthelist.ui" line="5915"/>
        <source>High</source>
        <translation>Výšky</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="7559"/>
        <source>MonitorPlayer</source>
        <translation>Sledování přehrávání</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="6890"/>
        <source>0:00.0</source>
        <translation>0:00.0</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="7615"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;settings&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#df0000;&quot;&gt;No 2nd soundcard selected!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;settings&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#df0000;&quot;&gt;Není vybrána žádná druhá zvuková karta!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="7192"/>
        <source>-0:00.0</source>
        <translation>-0:00.0</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="7640"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.cpp" line="188"/>
        <source>Collection</source>
        <translation>Sbírka</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.cpp" line="252"/>
        <source>AutoDJ</source>
        <translation>Diskžokej</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.cpp" line="260"/>
        <source>Folder</source>
        <translation>Složka</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.cpp" line="285"/>
        <source>Lists</source>
        <translation>Seznamy</translation>
    </message>
</context>
<context>
    <name>ModeSelector</name>
    <message>
        <location filename="../src/modeselector.ui" line="31"/>
        <source>Frame</source>
        <translatorcomment>no need to translate </translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="70"/>
        <source>View: Artist &gt; Album</source>
        <translation>Pohled: Umělec &gt;Alba </translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="101"/>
        <source>View: Year &gt; Artist &gt; Album</source>
        <translation>Pohled: Rok &gt; Umělec &gt;Alba</translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="104"/>
        <source>Y</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="132"/>
        <source>View: Genre &gt; Artist &gt; Album</source>
        <translation>Pohled: Žánr &gt; Umělec &gt;Alba</translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="135"/>
        <source>G</source>
        <translation>Ž</translation>
    </message>
</context>
<context>
    <name>PlayerWidget</name>
    <message>
        <location filename="../src/playerwidget.ui" line="20"/>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="754"/>
        <source>texttexttextt</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="855"/>
        <source>TextLabel</source>
        <translation>Textový štítek</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="1351"/>
        <source>00:00</source>
        <translation>00:00</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="2294"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; color:#ffffff;&quot;&gt;Time remain&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; color:#ffffff;&quot;&gt;Zbývající čas&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="2789"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; color:#ffffff;&quot;&gt;Seconds of silence at the end &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; color:#ffffff;&quot;&gt;Ticho na konci vyjádřeno počtem sekund &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="2795"/>
        <source>-00</source>
        <translation>-00</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="3048"/>
        <source>Jump to the point where the music starts mainly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jump to start position</source>
        <translation>Skočit na začáteční polohu</translation>
    </message>
    <message>
        <source>texttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttext</source>
        <translation type="obsolete">texttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttext</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="2300"/>
        <source>-00:00</source>
        <translation>-00:00</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="1809"/>
        <location filename="../src/playerwidget.ui" line="2758"/>
        <source>.00</source>
        <translation>.00</translation>
    </message>
    <message>
        <source>textLabel1</source>
        <translation type="obsolete">Textový štítek 1</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="3034"/>
        <source>Cue</source>
        <translation type="obsolete">ZNAČKA</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.cpp" line="127"/>
        <source>Tracks</source>
        <translation>skladeb</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.cpp" line="127"/>
        <source>Track</source>
        <translation>skladba</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.cpp" line="132"/>
        <source>Hours</source>
        <translation>hodin</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.cpp" line="354"/>
        <source>No track</source>
        <translation>Žádná skladba</translation>
    </message>
</context>
<context>
    <name>Playlist</name>
    <message>
        <source>Trackname</source>
        <translation type="obsolete">Název skladby</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <source>No</source>
        <translation>Čís</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <location filename="../src/playlist.cpp" line="1043"/>
        <source>Artist</source>
        <translation>Umělec</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <location filename="../src/playlist.cpp" line="1042"/>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <source>Url</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <source>Played</source>
        <translation>Hráno</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="72"/>
        <location filename="../src/playlist.cpp" line="1044"/>
        <source>Album</source>
        <translation>Alba</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="72"/>
        <location filename="../src/playlist.cpp" line="1046"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="73"/>
        <source>Rate</source>
        <translation>Hodnocení</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="obsolete">Poznámka</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="72"/>
        <location filename="../src/playlist.cpp" line="1045"/>
        <source>Genre</source>
        <translation>Žánr</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="72"/>
        <source>Track</source>
        <translation>Skladba</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation type="obsolete">Adresář</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="73"/>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation type="obsolete">Datový tok</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="973"/>
        <source>Add to PlayList&amp;1</source>
        <translation>Přidat do seznamu skladeb &amp;1</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="975"/>
        <source>Add to PlayList&amp;2</source>
        <translation>Přidat do seznamu skladeb &amp;2</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="979"/>
        <source>&amp;Load</source>
        <translation>&amp;Nahrát</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="982"/>
        <source>Load as &amp;Next</source>
        <translation>Nahrát jako &amp;další</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="985"/>
        <source>&amp;Prelisten Track</source>
        <translation>&amp;Slyšet skladbu předem</translation>
    </message>
    <message>
        <source>&amp;View Tag Information...</source>
        <translation type="obsolete">&amp;Zobrazit informace o skladbě...</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="988"/>
        <source>&amp;Search for: &apos;%1&apos;</source>
        <translation>&amp;Hledat: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="992"/>
        <source>&amp;Remove Selected</source>
        <translation>&amp;Odstranit vybrané</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="994"/>
        <source>&amp;Open File Location</source>
        <translation>Otevřít souborové umístění</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="996"/>
        <source>&amp;View Tag Information</source>
        <translation>&amp;Zobrazit informace o skladbě</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="1047"/>
        <source>Location</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="1050"/>
        <source>Meta Information</source>
        <translation>Popisné informace</translation>
    </message>
</context>
<context>
    <name>PlaylistBrowser</name>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="59"/>
        <source>Add a new list and store current tracks</source>
        <translation>Přidat nový seznam a uložit nynější skladby</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="118"/>
        <source>Top Tracks</source>
        <translation>Nejlepší skladby</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="120"/>
        <source>Most played tracks</source>
        <translation>Nejhranější skladby</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="133"/>
        <source>Last Tracks</source>
        <translation>Poslední skladby</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="135"/>
        <source>Recently played tracks</source>
        <translation>Nedávno přehrávané skladby</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="148"/>
        <source>Favorites Tracks</source>
        <translation>Oblíbené skladby</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="150"/>
        <source>High rated tracks</source>
        <translation>Vysoce hodnocené skladby</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="174"/>
        <source>tracks</source>
        <translation>skladeb</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="175"/>
        <source>hours</source>
        <translation>hodin</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="313"/>
        <source>Save Play List</source>
        <translation>Uložit seznam skladeb</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="314"/>
        <source>Enter a name for the new list</source>
        <translation>Zadejte název pro nový seznam</translation>
    </message>
</context>
<context>
    <name>PlaylistWidget</name>
    <message>
        <location filename="../src/playlistwidget.ui" line="14"/>
        <source>Frame</source>
        <translation>Rámeček</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="111"/>
        <source>Click here to show the content of this list</source>
        <translation>Klepněte sem pro ukázání obsahu tohoto seznamu</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="114"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;charts&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;Most Played&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;charts&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;Nejhranější&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="137"/>
        <source>TextLabel</source>
        <translation>Textový štítek</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="209"/>
        <source>Load all tracks of this list directly into player playlists</source>
        <translation>Nahrát všechny skladby tohoto seznamu přímo do seznamů skladeb přehrávače</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="236"/>
        <source>Remove this list</source>
        <translation>Odstranit tento seznam</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="239"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="264"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Confirm the remove&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Potvrdit odstranění&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="273"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="65"/>
        <location filename="../src/main.cpp" line="68"/>
        <source>Unable to load database</source>
        <translation>Nelze nahrát databázi</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="66"/>
        <source>This application needs the QT5 SQLITE driver (libqt5-sql-sqlite)</source>
        <translation type="unfinished">Tento program potřebuje ovladač QT4 SQLITE (libqt4-sql-sqlite) {5 ?} {5-?}</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="69"/>
        <source>This application needs the QT4 SQLITE driver (libqt4-sql-sqlite)</source>
        <translation>Tento program potřebuje ovladač QT4 SQLITE (libqt4-sql-sqlite)</translation>
    </message>
    <message>
        <source>Select folders for music collection</source>
        <translation type="obsolete">Vyberte složky pro hudební sbírku</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="52"/>
        <location filename="../src/playlistitem.cpp" line="53"/>
        <location filename="../src/playlistitem.cpp" line="80"/>
        <location filename="../src/playlistitem.cpp" line="122"/>
        <location filename="../src/playlistitem.cpp" line="135"/>
        <location filename="../src/track.cpp" line="134"/>
        <location filename="../src/track.cpp" line="135"/>
        <location filename="../src/track.cpp" line="136"/>
        <location filename="../src/track.cpp" line="138"/>
        <location filename="../src/track.cpp" line="146"/>
        <location filename="../src/track.cpp" line="244"/>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="65"/>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="66"/>
        <source>Artist</source>
        <translation>Umělec</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="67"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="68"/>
        <source>Genre</source>
        <translation>Žánr</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="69"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="70"/>
        <source>Location</source>
        <translation>Umístění</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.ui" line="20"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>New Row</source>
        <translation type="obsolete">Nový řádek</translation>
    </message>
    <message>
        <source>Neue Zeile</source>
        <translation type="obsolete">Nový řádek</translation>
    </message>
    <message>
        <source>New Column</source>
        <translation type="obsolete">Nový sloupec</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="141"/>
        <source>Fader</source>
        <translation>Prolínač</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="146"/>
        <source>Collection</source>
        <translation>Sbírka</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="151"/>
        <source>Audio devices</source>
        <translation>Zvuková zařízení</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="156"/>
        <source>AutoDJ</source>
        <translation>Diskžokej</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="161"/>
        <source>Playlists</source>
        <translation>Seznamy skladeb</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="166"/>
        <source>File browser</source>
        <translation>Prohlížeč souborů</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="171"/>
        <source>Common</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="198"/>
        <source>Fader settings</source>
        <translation>Nastavení prolínání</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="236"/>
        <source>Start fading before song end</source>
        <translation>Začít s prolínáním před koncem písně</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="265"/>
        <location filename="../src/settingsdialog.ui" line="291"/>
        <source>12s</source>
        <translation>12 s</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="278"/>
        <source>Fader Time</source>
        <translation>Čas prolínání</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="326"/>
        <source>Skip silent at start (AutoCue)</source>
        <translation>Přeskočit ticho na začátku</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="342"/>
        <source>Skip silent at the end</source>
        <translation>Přeskočit ticho na konci</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="374"/>
        <source>Scan for new files and update the music collection</source>
        <translation>Hledat nové soubory a aktualizovat sbírku</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="377"/>
        <source>Watch folders for changes</source>
        <translation>Sledovat změny ve složkách</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="399"/>
        <source>Scan Now</source>
        <translation>Prohledat nyní</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="406"/>
        <source>Scan folders for songs</source>
        <translation>Hledat písně ve složkách</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="413"/>
        <source>Play Counter Statistics</source>
        <translation>Statistika počítadla přehrávání</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="420"/>
        <source>Reset</source>
        <translation>Vynulovat</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="442"/>
        <source>Monitor Player</source>
        <translation>Přehrávání</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="465"/>
        <source>Device Settings</source>
        <translation>Nastavení zařízení</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="496"/>
        <source>AutoDJ settings</source>
        <translation>Nastavení automatického diskžokeje</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="538"/>
        <source>Minimum tracks within each playlist </source>
        <translation>Nejmenší počet skladeb v každém seznamu skladeb </translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="717"/>
        <source>File Browser Settings</source>
        <translation>Nastavení prohlížeče souborů</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="794"/>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="807"/>
        <source>Common Settings</source>
        <translation>Obecná nastavení</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="841"/>
        <source>Change the language of the application (needs restart)</source>
        <translation>Změnit jazyk aplikace (vyžaduje opětovné spuštění programu)</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="867"/>
        <source>About</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>Minimum Tracks</source>
        <translation type="obsolete">Nejmenší počet skladeb</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="564"/>
        <source>DJ Count</source>
        <translation>Počet diskžokejů</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="596"/>
        <source>DJ Names</source>
        <translation>Jména diskžokejů</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="609"/>
        <source>Filter Count</source>
        <translation>Počet filtrů</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="622"/>
        <source>Increment play counter for AutoDj selected tracks</source>
        <translation>Čítač přehrávaných skladeb vybraných automatickým diskžokejem</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="653"/>
        <source>Auto Remove Played Tracks</source>
        <translation>Odstranit přehrané skladby automaticky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="666"/>
        <source>Playlist Settings</source>
        <translation>Nastavení seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="691"/>
        <source>Browser Root</source>
        <translation>Výchozí cesta</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="704"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="276"/>
        <source>About Knowthelist</source>
        <translation>O programu Knowthelist</translation>
    </message>
</context>
</TS>
